@@ -1,7 +1,7 @@
 #ifndef _RS_MYSQL_H
 #define _RS_MYSQL_H 1
 /*  
- *  $Id: RS-MySQL.h 157 2006-02-15 18:01:03Z dj $
+ *  $Id: RS-MySQL.h 298 2007-05-23 11:50:13Z daj025@gmail.com $
  *
  * Copyright (C) 1999-2002 The Omega Project for Statistical Computing.
  *
@@ -56,13 +56,13 @@ extern  "C" {
  * themselves.
  */
 typedef struct st_sdbi_conParams {
-  char *host;
-  char *dbname;
-  char *user;
-  char *passwd;
-  char *unix_socket;
-  unsigned int  port; 
-  unsigned int  client_flags;
+    char *host;
+    char *dbname;
+    char *user;
+    char *passwd;
+    char *unix_socket;
+    unsigned int  port; 
+    unsigned int  client_flags;
 } RS_MySQL_conParams;
 
 RS_MySQL_conParams *RS_MySQL_allocConParams(void);
@@ -85,10 +85,10 @@ s_object   *RS_MySQL_close(Mgr_Handle *mgrHandle);
 
 /* dbConnection */
 Con_Handle *RS_MySQL_newConnection(Mgr_Handle *mgrHandle, 
-				   s_object *con_params,
-				   s_object *MySQLgroups,
-				   s_object *s_mysql_default_file);
-Con_Handle *RS_MySQL_cloneConnection(Con_Handle *conHandle);
+    s_object *con_params,
+    s_object *MySQLgroups,
+    s_object *s_mysql_default_file);
+    Con_Handle *RS_MySQL_cloneConnection(Con_Handle *conHandle);
 s_object   *RS_MySQL_closeConnection(Con_Handle *conHandle);
 s_object   *RS_MySQL_getException(Con_Handle *conHandle);    /* err No, Msg */
 
@@ -97,6 +97,10 @@ Res_Handle *RS_MySQL_exec(Con_Handle *conHandle, s_object *statement);
 s_object   *RS_MySQL_fetch(Res_Handle *rsHandle, s_object *max_rec);
 s_object   *RS_MySQL_closeResultSet(Res_Handle *rsHandle); 
 
+/* Multiple result set function (as of MySQL Version 4.1) */
+Res_Handle *RS_MySQL_nextResultSet(Con_Handle *conHandle);
+s_object   *RS_MySQL_moreResultSets(Con_Handle *conHandle);  /* boolean */
+
 s_object   *RS_MySQL_validHandle(Db_Handle *handle);      /* boolean */
 
 RS_DBI_fields *RS_MySQL_createDataMappings(Res_Handle *resHandle);
@@ -107,32 +111,34 @@ s_object *RS_MySQL_managerInfo(Mgr_Handle *mgrHandle);
 s_object *RS_MySQL_connectionInfo(Con_Handle *conHandle);
 s_object *RS_MySQL_resultSetInfo(Res_Handle *rsHandle);
 
+s_object *RS_MySQL_escapeStrings(Con_Handle *conHandle, s_object *statement);
+
 /* the following type names are from "mysql_com.h" */
 static struct data_types RS_MySQL_dataTypes[] = {
-    { "FIELD_TYPE_DECIMAL",	FIELD_TYPE_DECIMAL	},
-    { "FIELD_TYPE_TINY",	FIELD_TYPE_TINY		},
-    { "FIELD_TYPE_SHORT",	FIELD_TYPE_SHORT	},
-    { "FIELD_TYPE_LONG",	FIELD_TYPE_LONG		},
-    { "FIELD_TYPE_FLOAT",	FIELD_TYPE_FLOAT	},
-    { "FIELD_TYPE_DOUBLE",	FIELD_TYPE_DOUBLE	},
-    { "FIELD_TYPE_NULL",	FIELD_TYPE_NULL		},
-    { "FIELD_TYPE_TIMESTAMP",   FIELD_TYPE_TIMESTAMP	},
-    { "FIELD_TYPE_LONGLONG",	FIELD_TYPE_LONGLONG	},
-    { "FIELD_TYPE_INT24",	FIELD_TYPE_INT24	},
-    { "FIELD_TYPE_DATE",	FIELD_TYPE_DATE		},
-    { "FIELD_TYPE_TIME",	FIELD_TYPE_TIME		},
-    { "FIELD_TYPE_DATETIME",	FIELD_TYPE_DATETIME	},
-    { "FIELD_TYPE_YEAR",	FIELD_TYPE_YEAR		},
-    { "FIELD_TYPE_NEWDATE",	FIELD_TYPE_NEWDATE	},
-    { "FIELD_TYPE_ENUM",	FIELD_TYPE_ENUM		},
-    { "FIELD_TYPE_SET",		FIELD_TYPE_SET		},
-    { "FIELD_TYPE_TINY_BLOB",	FIELD_TYPE_TINY_BLOB	},
-    { "FIELD_TYPE_MEDIUM_BLOB",	FIELD_TYPE_MEDIUM_BLOB	},
-    { "FIELD_TYPE_LONG_BLOB",	FIELD_TYPE_LONG_BLOB	},
-    { "FIELD_TYPE_BLOB",	FIELD_TYPE_BLOB		},
-    { "FIELD_TYPE_VAR_STRING",	FIELD_TYPE_VAR_STRING	},
-    { "FIELD_TYPE_STRING",	FIELD_TYPE_STRING	},
-    { (char *) 0,			-1		}
+    { "FIELD_TYPE_DECIMAL",    FIELD_TYPE_DECIMAL},
+    { "FIELD_TYPE_TINY",       FIELD_TYPE_TINY},
+    { "FIELD_TYPE_SHORT",      FIELD_TYPE_SHORT},
+    { "FIELD_TYPE_LONG",       FIELD_TYPE_LONG},
+    { "FIELD_TYPE_FLOAT",      FIELD_TYPE_FLOAT},
+    { "FIELD_TYPE_DOUBLE",     FIELD_TYPE_DOUBLE},
+    { "FIELD_TYPE_NULL",       FIELD_TYPE_NULL},
+    { "FIELD_TYPE_TIMESTAMP",  FIELD_TYPE_TIMESTAMP},
+    { "FIELD_TYPE_LONGLONG",   FIELD_TYPE_LONGLONG},
+    { "FIELD_TYPE_INT24",      FIELD_TYPE_INT24},
+    { "FIELD_TYPE_DATE",       FIELD_TYPE_DATE},
+    { "FIELD_TYPE_TIME",       FIELD_TYPE_TIME},
+    { "FIELD_TYPE_DATETIME",   FIELD_TYPE_DATETIME},
+    { "FIELD_TYPE_YEAR",       FIELD_TYPE_YEAR},
+    { "FIELD_TYPE_NEWDATE",    FIELD_TYPE_NEWDATE},
+    { "FIELD_TYPE_ENUM",       FIELD_TYPE_ENUM},
+    { "FIELD_TYPE_SET",        FIELD_TYPE_SET},
+    { "FIELD_TYPE_TINY_BLOB",  FIELD_TYPE_TINY_BLOB},
+    { "FIELD_TYPE_MEDIUM_BLOB",FIELD_TYPE_MEDIUM_BLOB},
+    { "FIELD_TYPE_LONG_BLOB",  FIELD_TYPE_LONG_BLOB},
+    { "FIELD_TYPE_BLOB",       FIELD_TYPE_BLOB},
+    { "FIELD_TYPE_VAR_STRING", FIELD_TYPE_VAR_STRING},
+    { "FIELD_TYPE_STRING",     FIELD_TYPE_STRING},
+    { (char *) 0, -1 }
 };
 
 s_object *RS_MySQL_typeNames(s_object *typeIds);
